@@ -170,6 +170,30 @@ long DialogBox::onKeyPress(FXObject* sender, FXSelector sel, void* ptr)
         handle(this, FXSEL(SEL_COMMAND, ID_CANCEL), NULL);
         return(1);
     }
+
+
+
+    FXEvent* event = (FXEvent*)ptr;
+
+    switch (event->code)
+    {
+    case KEY_Escape:
+        handle(this, FXSEL(SEL_COMMAND, ID_CANCEL), NULL);
+        return(1);
+
+    case KEY_KP_Enter:
+    case KEY_Return:
+        handle(this, FXSEL(SEL_COMMAND, ID_ACCEPT), NULL);
+        return(1);
+
+    default:
+        FXTopWindow::onKeyPress(sender, sel, ptr);
+        return(1);
+    }
+
+
+
+
     return(0);
 }
 
