@@ -24,17 +24,18 @@ protected:
     ExecuteBox(const ExecuteBox&)
     {}
 public:
-    long onCmdClicked(FXObject*,FXSelector,void*);
+    long onCmdClicked(FXObject*, FXSelector, void*);
 public:
-    enum{
+    enum
+    {
         ID_CLICKED_CANCEL=DialogBox::ID_LAST,
-		ID_CLICKED_EXECUTE,
+        ID_CLICKED_EXECUTE,
         ID_CLICKED_CONSOLE,
         ID_CLICKED_EDIT,
         ID_LAST
     };
 public:
-    ExecuteBox(FXWindow *win,const FXString& name,const FXString& text,FXuint opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0);
+    ExecuteBox(FXWindow* win, const FXString& name, const FXString& text, FXuint opts = DECOR_TITLE|DECOR_BORDER, int x = 0, int y = 0);
 };
 
 #endif
