@@ -2075,8 +2075,6 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
         return(-1);
     }
 
-
-
     // Perform the mount/unmount command
     FILE* pcmd = popen(cmd.text(), "r");
     if (!pcmd)
@@ -2101,38 +2099,6 @@ int File::mount(const FXString dir, const FXString msg, const FXString cmd, cons
         return(-1);
     }
 
-
-
-#ifdef ZZZ
-
-FXString title = "titre";
-
-fprintf(stderr,"cmd = %s\n", cmd.text());
-
-
-FXString command;
- 
- // Semble marcher (il ne faut pas mettre le 2>&1 à la fin de la commande sinon ne marche pas !
- // L'enlever de DirPanel.cpp et FilePanel.cpp si besoin !
- command = "st -g 60x4 -t " + ::quote(title) + " " + cmd;
-
- 
-fprintf(stderr,"command = %s\n",command.text());
-
-    // Execute su or sudo command in an internal st terminal
-    int status = runst(command);
-
-
-    if (status<0)
-    {
-        MessageBox::error(getApp(),BOX_OK,_("Error"),_("!!!!!An error has occurred!"));
-        //getApp()->endWaitCursor();
-        return (-1);
-    }
-
-#endif
-
-
     // Hide progress dialog
     hide();
 
