@@ -1629,7 +1629,7 @@ long FileSelector::onCmdKeyPress(FXObject* sender, FXSelector sel, void* ptr)
     // Any other key was pressed : handle the pressed key in the usual way
     else
     {
-        if (list->onKeyPress(sender, sel, ptr))
+        if (this->onKeyPress(sender, sel, ptr))
         {
             return(1);
         }
@@ -1640,7 +1640,7 @@ long FileSelector::onCmdKeyPress(FXObject* sender, FXSelector sel, void* ptr)
 
 long FileSelector::onCmdKeyRelease(FXObject* sender, FXSelector sel, void* ptr)
 {
-    if (list->onKeyRelease(sender, sel, ptr))
+    if (this->onKeyRelease(sender, sel, ptr))
     {
         return(1);
     }
