@@ -10,14 +10,15 @@ class FileList;
 
 
 // Additional mode for file selection : same as SELECTFILE_DIRECTORY but with the ability to also select files
-enum {
-		SELECT_FILE_ANY,             // A single file, existing or not (to save to)
-		SELECT_FILE_EXISTING,        // An existing file (to load), but not '.' and '..'
-		SELECT_FILE_MULTIPLE,        // Multiple existing files
-		SELECT_FILE_MULTIPLE_ALL,    // Multiple existing files or directories, but not '.' and '..'
-		SELECT_FILE_DIRECTORY,       // Existing directory, including '.' or '..'
-		SELECT_FILE_MIXED,           // An existing file or directory, including '.' and '..'
-	};
+enum
+{
+    SELECT_FILE_ANY,             // A single file, existing or not (to save to)
+    SELECT_FILE_EXISTING,        // An existing file (to load), but not '.' and '..'
+    SELECT_FILE_MULTIPLE,        // Multiple existing files
+    SELECT_FILE_MULTIPLE_ALL,    // Multiple existing files or directories, but not '.' and '..'
+    SELECT_FILE_DIRECTORY,       // Existing directory, including '.' or '..'
+    SELECT_FILE_MIXED,           // An existing file or directory, including '.' and '..'
+};
 
 
 // File selection widget
@@ -25,79 +26,86 @@ class FXAPI FileSelector : public FXPacker
 {
     FXDECLARE(FileSelector)
 protected:
-    FileList      *list;            // File list widget
-    FXTextField   *filename;        // File name entry field
-    FXComboBox    *filefilter;      // Combobox for pattern list
-    FXCheckButton *readonly;        // Open file as read only
-    FXButton      *accept;          // Accept button
-    FXButton      *cancel;          // Cancel button
+    FileList*      list;            // File list widget
+    FXTextField*   filename;        // File name entry field
+    FXComboBox*    filefilter;      // Combobox for pattern list
+    FXCheckButton* readonly;        // Open file as read only
+    FXButton*      accept;          // Accept button
+    FXButton*      cancel;          // Cancel button
     FXuint         selectmode;      // Select mode
-	FXArrowButton   *btnbackhist;     // Back history
-	FXArrowButton   *btnforwardhist;  // Forward history
-    PathLinker*		  pathlink;
-	TextLabel*	      pathtext;
+    FXArrowButton* btnbackhist;     // Back history
+    FXArrowButton* btnforwardhist;  // Forward history
+    PathLinker*    pathlink;
+    TextLabel*     pathtext;
 protected:
-    FileSelector()
+    FileSelector() : list(NULL), filename(NULL), filefilter(NULL), readonly(NULL), accept(NULL), cancel(NULL),
+                     selectmode(0), btnbackhist(NULL), btnforwardhist(NULL), pathlink(NULL), pathtext(NULL)
     {}
     virtual void create();
     static FXString patternFromText(const FXString& pattern);
     static FXString extensionFromPattern(const FXString& pattern);
+
 private:
     FileSelector(const FileSelector&);
-    FileSelector &operator=(const FileSelector&);
+    FileSelector& operator=(const FileSelector&);
+
 public:
-    long onCmdAccept(FXObject*,FXSelector,void*);
-    long onCmdFilter(FXObject*,FXSelector,void*);
-    long onCmdItemDoubleClicked(FXObject*,FXSelector,void*);
-    long onCmdItemClicked(FXObject*,FXSelector,void*);
-    long onCmdItemSelected(FXObject*,FXSelector,void*);
-    long onCmdItemDeselected(FXObject*,FXSelector,void*);
-    long onCmdDirUp(FXObject*,FXSelector,void*);
-    long onUpdDirUp(FXObject*,FXSelector,void*);
-	long onCmdDirBack(FXObject*,FXSelector,void*);
-    long onUpdDirBack(FXObject*,FXSelector,void*);
- 	long onCmdDirForward(FXObject*,FXSelector,void*);
-    long onUpdDirForward(FXObject*,FXSelector,void*);
-	long onCmdDirBackHist(FXObject*,FXSelector,void*);
-    long onUpdDirBackHist(FXObject*,FXSelector,void*);
- 	long onCmdDirForwardHist(FXObject*,FXSelector,void*);
-    long onUpdDirForwardHist(FXObject*,FXSelector,void*);
-    long onCmdHome(FXObject*,FXSelector,void*);
-    long onCmdWork(FXObject*,FXSelector,void*);
-	long onCmdNewDir(FXObject*,FXSelector,void*);
-	long onCmdNewFile(FXObject*,FXSelector,void*);
-	long onCmdPopupMenu(FXObject*,FXSelector,void*);
+    long onCmdAccept(FXObject*, FXSelector, void*);
+    long onCmdFilter(FXObject*, FXSelector, void*);
+    long onCmdItemDoubleClicked(FXObject*, FXSelector, void*);
+    long onCmdItemClicked(FXObject*, FXSelector, void*);
+    long onCmdItemSelected(FXObject*, FXSelector, void*);
+    long onCmdItemDeselected(FXObject*, FXSelector, void*);
+    long onCmdDirUp(FXObject*, FXSelector, void*);
+    long onUpdDirUp(FXObject*, FXSelector, void*);
+    long onCmdDirBack(FXObject*, FXSelector, void*);
+    long onUpdDirBack(FXObject*, FXSelector, void*);
+    long onCmdDirForward(FXObject*, FXSelector, void*);
+    long onUpdDirForward(FXObject*, FXSelector, void*);
+    long onCmdDirBackHist(FXObject*, FXSelector, void*);
+    long onUpdDirBackHist(FXObject*, FXSelector, void*);
+    long onCmdDirForwardHist(FXObject*, FXSelector, void*);
+    long onUpdDirForwardHist(FXObject*, FXSelector, void*);
+    long onCmdHome(FXObject*, FXSelector, void*);
+    long onCmdWork(FXObject*, FXSelector, void*);
+    long onCmdNewDir(FXObject*, FXSelector, void*);
+    long onCmdNewFile(FXObject*, FXSelector, void*);
+    long onCmdPopupMenu(FXObject*, FXSelector, void*);
+	long onCmdKeyPress(FXObject*, FXSelector, void*);
+	long onCmdKeyRelease(FXObject*, FXSelector, void*);
 public:
-    enum {
+    enum
+    {
         ID_FILEFILTER=FXPacker::ID_LAST,
         ID_ACCEPT,
         ID_FILELIST,
+        ID_POPUP_MENU,
         ID_DIR_UP,
-		ID_DIR_BACK,
-		ID_DIR_FORWARD,
- 		ID_DIR_BACK_HIST,
-		ID_DIR_FORWARD_HIST,
+        ID_DIR_BACK,
+        ID_DIR_FORWARD,
+        ID_DIR_BACK_HIST,
+        ID_DIR_FORWARD_HIST,
         ID_HOME,
         ID_WORK,
-		ID_NEWDIR,
-		ID_NEWFILE,
+        ID_NEWDIR,
+        ID_NEWFILE,
         ID_LAST
     };
 public:
 
     // Constructor
-    FileSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,int x=0,int y=0,int w=0,int h=0);
+    FileSelector(FXComposite* p, FXObject* tgt = NULL, FXSelector sel = 0, FXuint opts = 0, int x = 0, int y = 0, int w = 0, int h = 0);
 
     // Return a pointer to the "Accept" button
-    FXButton *acceptButton() const
+    FXButton* acceptButton() const
     {
-        return accept;
+        return(accept);
     }
 
     // Return a pointer to the "Cancel" button
-    FXButton *cancelButton() const
+    FXButton* cancelButton() const
     {
-        return cancel;
+        return(cancel);
     }
 
     // Change file name
@@ -134,7 +142,7 @@ public:
     // Set list of patterns as name,pattern pairs.
     // The list should be terminated with a final NULL string.
     // (DEPRECATED)
-    void setPatternList(const char **ptrns);
+    void setPatternList(const char** ptrns);
 
     // Return list of patterns
     FXString getPatternList() const;
@@ -150,7 +158,7 @@ public:
     FXString getPatternText(int patno) const;
 
     // Change pattern text for pattern number
-    void setPatternText(int patno,const FXString& text);
+    void setPatternText(int patno, const FXString& text);
 
     // Change directory
     void setDirectory(const FXString& path);
@@ -176,7 +184,7 @@ public:
     // Return file selection mode
     FXuint getSelectMode() const
     {
-        return selectmode;
+        return(selectmode);
     }
 
     // Show readonly button
@@ -192,18 +200,18 @@ public:
     FXbool getReadOnly() const;
 
     // Return true if hidden files are shown
-	FXbool shownHiddenFiles() const;
+    FXbool shownHiddenFiles() const;
 
     // Return true if thumbnails are shown
-	FXbool shownThumbnails() const;
+    FXbool shownThumbnails() const;
 
-	// Change show hidden files mode
-	void showHiddenFiles(FXbool shown);
+    // Change show hidden files mode
+    void showHiddenFiles(FXbool shown);
 
-	// Change show thumbnails files mode
-	void showThumbnails(FXbool shown);
+    // Change show thumbnails files mode
+    void showThumbnails(FXbool shown);
 
-	// Destructor
+    // Destructor
     virtual ~FileSelector();
 };
 
@@ -213,22 +221,23 @@ class FXAPI FileDialog : public DialogBox
 {
     FXDECLARE(FileDialog)
 protected:
-    FileSelector *list;
+    FileSelector* list;
 protected:
-    FileDialog()
+    FileDialog() : list(NULL)
     {}
 private:
     FileDialog(const FileDialog&);
-    FileDialog &operator=(const FileDialog&);
+    FileDialog& operator=(const FileDialog&);
+
 public:
 
     // Construct File Dialog Box
-    FileDialog(FXWindow* owner,const FXString& name,FXuint opts=0,int x=0,int y=0,int w=500,int h=300);
+    FileDialog(FXWindow* owner, const FXString& name, FXuint opts = 0, int x = 0, int y = 0, int w = 500, int h = 300);
 
     // Change file name
     void setFilename(const FXString& path);
 
-	// Return file name, if any
+    // Return file name, if any
     FXString getFilename() const;
 
     // Return empty-string terminated list of selected file names, or NULL if none selected
@@ -257,7 +266,7 @@ public:
     // Set list of patterns as name,pattern pairs.
     // The list should be terminated with a final NULL string.
     // (DEPRECATED)
-    void setPatternList(const char **ptrns);
+    void setPatternList(const char** ptrns);
 
     // Return list of patterns
     FXString getPatternList() const;
@@ -273,7 +282,7 @@ public:
     FXString getPatternText(int patno) const;
 
     // Change pattern text for pattern number
-    void setPatternText(int patno,const FXString& text);
+    void setPatternText(int patno, const FXString& text);
 
     // Change directory
     void setDirectory(const FXString& path);
@@ -304,36 +313,36 @@ public:
 
     // Return true if readonly is shown
     FXbool shownReadOnly() const;
-	
+
     // Return true if hidden files are shown
-	FXbool shownHiddenFiles() const;
+    FXbool shownHiddenFiles() const;
 
     // Return true if thumbnails are shown
-	FXbool shownThumbnails() const;
+    FXbool shownThumbnails() const;
 
-	// Change show hidden files mode
-	void showHiddenFiles(FXbool shown);
+    // Change show hidden files mode
+    void showHiddenFiles(FXbool shown);
 
-	// Change show thumbnails files mode
-	void showThumbnails(FXbool shown);
+    // Change show thumbnails files mode
+    void showThumbnails(FXbool shown);
 
-	// Set initial state of readonly button
+    // Set initial state of readonly button
     void setReadOnly(FXbool state);
 
     // Get readonly state
     FXbool getReadOnly() const;
 
     // Open existing filename
-    static FXString getOpenFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns="*",int initial=0);
+    static FXString getOpenFilename(FXWindow* owner, const FXString& caption, const FXString& path, const FXString& patterns = "*", int initial = 0);
 
     // Open multiple existing files
-    static FXString* getOpenFilenames(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns="*",int initial=0);
+    static FXString* getOpenFilenames(FXWindow* owner, const FXString& caption, const FXString& path, const FXString& patterns = "*", int initial = 0);
 
     // Save to filename
-    static FXString getSaveFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns="*",int initial=0);
+    static FXString getSaveFilename(FXWindow* owner, const FXString& caption, const FXString& path, const FXString& patterns = "*", int initial = 0);
 
     // Open directory name
-    static FXString getOpenDirectory(FXWindow* owner,const FXString& caption,const FXString& path);
+    static FXString getOpenDirectory(FXWindow* owner, const FXString& caption, const FXString& path);
 
     // Destructor
     virtual ~FileDialog();
