@@ -5,6 +5,7 @@
 
 #include <fx.h>
 
+#include "xfedefs.h"
 #include "xfeutils.h"
 #include "FontDialog.h"
 
@@ -150,7 +151,8 @@ FontSelector::FontSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
     preview = new FXLabel(scroll, "ABCDEFGHIJKLMNOPQRSTUVWXYZ\nabcdefghijklmnopqrstuvwxyz\n0123456789", NULL, JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y);
     preview->setBackColor(getApp()->getBackColor());
 
-    strlcpy(selected.face, "Helvetica", sizeof(selected.face)+1);
+	FXString fontname = FXString(DEFAULT_NORMAL_FONT);
+    strlcpy(selected.face, fontname.before(',').text(), sizeof(selected.face)+1);
     selected.size = 90;
     selected.weight = FXFont::Bold;
     selected.slant = 0;
