@@ -163,7 +163,7 @@ long MessageBox::onCmdSu(FXObject*, FXSelector sel, void*)
     }
 
     // Get text font
-    FXString fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", "Courier,100,normal,regular");
+    FXString fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     if (fontspec.empty())
     {
 		command = "st -t " + ::quote(title) + sucmd;
