@@ -1112,7 +1112,24 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString* file, int n, FXString* pat
     // Number of selected files
     snprintf(buf, sizeof(buf)-1, _("%d items"), num);
     filesSelected->setText(buf);
-    snprintf(buf, sizeof(buf)-1, _("%d files, %d folders"), nbselfiles, nbseldirs+dotdot);
+
+	if (nbselfiles <= 1 && nbseldirs+dotdot <= 1)
+	{
+	    snprintf(buf, sizeof(buf)-1, _("%d file, %d folder"), nbselfiles, nbseldirs+dotdot);
+	}
+	else if (nbselfiles <= 1 && nbseldirs+dotdot > 1)
+	{
+	    snprintf(buf, sizeof(buf)-1, _("%d file, %d folders"), nbselfiles, nbseldirs+dotdot);
+	}
+	else if (nbselfiles > 1 && nbseldirs+dotdot <= 1)
+	{
+	    snprintf(buf, sizeof(buf)-1, _("%d files, %d folder"), nbselfiles, nbseldirs+dotdot);
+	}
+	else
+	{
+	    snprintf(buf, sizeof(buf)-1, _("%d files, %d folders"), nbselfiles, nbseldirs+dotdot);
+	}
+
     filesSelectedDetails->setText(buf);
 
     // Display type of selected files
@@ -2068,7 +2085,23 @@ long PropertiesBox::onWatchProcess(FXObject*, FXSelector, void*)
 #endif	
 					fileSize->setText(size);
 
-					snprintf(size, sizeof(size)-1, _("%u files, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);
+					if (nbfiles-nbsubdirs-nbseldirs <= 1 && nbsubdirs <= 1)
+					{
+						snprintf(size, sizeof(size)-1, _("%u file, %u subfolder"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+					}
+					else if (nbfiles-nbsubdirs-nbseldirs <= 1 && nbsubdirs > 1)
+					{
+						snprintf(size, sizeof(size)-1, _("%u file, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+					}
+					else if (nbfiles-nbsubdirs-nbseldirs > 1 && nbsubdirs <= 1)
+					{
+						snprintf(size, sizeof(size)-1, _("%u files, %u subfolder"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+					}
+					else
+					{
+						snprintf(size, sizeof(size)-1, _("%u files, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+					}
+
 					fileSizeDetails->setText(size);
 
 					if (nread < (int)(sizeof(buf)-1))
@@ -2118,7 +2151,23 @@ long PropertiesBox::onWatchProcess(FXObject*, FXSelector, void*)
 #endif
 				fileSize->setText(size);
 
-				snprintf(size, sizeof(size)-1, _("%u files, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);
+				if (nbfiles-nbsubdirs-nbseldirs <= 1 && nbsubdirs <= 1)
+				{
+					snprintf(size, sizeof(size)-1, _("%u file, %u subfolder"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+				}
+				else if (nbfiles-nbsubdirs-nbseldirs <= 1 && nbsubdirs > 1)
+				{
+					snprintf(size, sizeof(size)-1, _("%u file, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+				}
+				else if (nbfiles-nbsubdirs-nbseldirs > 1 && nbsubdirs <= 1)
+				{
+					snprintf(size, sizeof(size)-1, _("%u files, %u subfolder"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+				}
+				else
+				{
+					snprintf(size, sizeof(size)-1, _("%u files, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);					
+				}
+
 				fileSizeDetails->setText(size);
 			}
 
