@@ -112,13 +112,13 @@ SearchWindow::SearchWindow(FXApp* app, const FXString& name, FXuint opts, int x,
     FXMatrix* matrix4 = new FXMatrix(moregroup, 6, MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|PACK_UNIFORM_WIDTH, 0, 0, 0, 0, 4, 4, 4, 8, 4, 8);
     new FXLabel(matrix4, _("Min size:"), NULL, JUSTIFY_LEFT);
     minsize = new FXSpinner(matrix4, 10, this, SearchWindow::ID_SIZE, SPIN_NOMAX|JUSTIFY_LEFT);
-    minsize->setTipText(_("Filter by minimum file size (KBytes)"));
-    new FXLabel(matrix4, _("KB"), NULL, JUSTIFY_LEFT);
+    minsize->setTipText(_("Filter by minimum file size (kBytes)"));
+    new FXLabel(matrix4, _("kB"), NULL, JUSTIFY_LEFT);
 
     new FXLabel(matrix4, _("Max size:"), NULL, JUSTIFY_LEFT);
     maxsize = new FXSpinner(matrix4, 10, this, SearchWindow::ID_SIZE, SPIN_NOMAX|JUSTIFY_LEFT);
-    maxsize->setTipText(_("Filter by maximum file size (KBytes)"));
-    new FXLabel(matrix4, _("KB"), NULL, JUSTIFY_LEFT);
+    maxsize->setTipText(_("Filter by maximum file size (kBytes)"));
+    new FXLabel(matrix4, _("kB"), NULL, JUSTIFY_LEFT);
 
     // Modification date
     new FXLabel(matrix4, _("Last modified before:"), NULL, JUSTIFY_LEFT);
