@@ -7,13 +7,14 @@ class TextWindow : public DialogBox
 {
     FXDECLARE(TextWindow)
 protected:
-    FXText *text;
+    FXText* text;
 private:
-    TextWindow()
+    TextWindow() : text(NULL)
     {}
     TextWindow(const TextWindow&);
 public:
-    enum{
+    enum
+    {
         ID_CLOSE=DialogBox::ID_LAST,
         ID_LAST
     };
@@ -21,11 +22,11 @@ public:
     TextWindow(FXWindow* owner, const FXString& name, int nblines, int nbcols);
     TextWindow(FXApp* app, const FXString& name, int nblines, int nbcols);
     virtual ~TextWindow();
-	void setText(const char*);
-	void appendText(const char*);
-	void scrollToLastLine(void);
-	void setFont(FXFont*);
-	int getLength(void);
+    void setText(const char*);
+    void appendText(const char*);
+    void scrollToLastLine(void);
+    void setFont(FXFont*);
+    int getLength(void);
 };
 
 #endif
