@@ -1607,12 +1607,12 @@ long WriteWindow::onCmdOpenRecent(FXObject*, FXSelector, void* ptr)
 // See if we can get it as a filename
 long WriteWindow::onEditDNDDrop(FXObject*, FXSelector, void*)
 {
-    char*  data;
+    FXuchar*  data;
     FXuint len;
 
-    if (getDNDData(FROM_DRAGNDROP, urilistType, (FXuchar*&)data, len))
+    if (getDNDData(FROM_DRAGNDROP, urilistType, data, len))
     {
-        FXString urilist(data, len);
+        FXString urilist((FXchar*)data, len);
         FXString file = FXURL::fileFromURL(urilist.before('\r'));
         FXFREE(&data);
         if (file.empty())
@@ -1710,10 +1710,10 @@ long WriteWindow::onUpdReadOnly(FXObject* sender, FXSelector, void*)
 
     // Disable cut and paste commands
     // (note: it seems that the context menu commands can't be disabled)
-    paste->disable();
-    pastemc->disable();
-    cut->disable();
-    cutmc->disable();
+    //paste->disable();
+    //pastemc->disable();
+    //cut->disable();
+    //cutmc->disable();
 
     return(1);
 }
