@@ -224,7 +224,7 @@ int main(int argc, char* argv[])
 
     // Set Xfw normal font according to the Xfe registry
     FXString fontspec;
-    fontspec = reg_xfe->readStringEntry("SETTINGS", "font", "Helvetica,100,normal,regular");
+    fontspec = reg_xfe->readStringEntry("SETTINGS", "font", DEFAULT_NORMAL_FONT);
     if (!fontspec.empty())
     {
         FXFont* normalFont = new FXFont(application, fontspec);
