@@ -285,6 +285,7 @@ int main(int argc, char* argv[])
     FXbool      iconic = false;
     FXbool      maximized = false;
     FXString    xmodifiers;
+    FXString	cmd;
 
     // Vector of URIs to open on startup
     vector_FXString startURIs;
@@ -335,7 +336,7 @@ int main(int argc, char* argv[])
     //   - else if rpm exists, then the system uses rpm packages
     //   - else another (unsupported) package manager is used
 
-    FXString cmd = "dpkg --version";
+    cmd = "dpkg --version";
     FXString str = getCommandOutput(cmd);
 
     if (str.find("Debian") != -1)
