@@ -902,8 +902,8 @@ FXulong pathsize(char* path, FXuint* nbfiles, FXuint* nbsubdirs, FXulong *totals
 }
 
 
-// Write the file size in human readable form (bytes or Kbytes or Mbytes)
-// We use a decimal basis for KB, MB, GB count
+// Write the file size in human readable form (bytes, kBytes, MBytes, GBytes)
+// We use a decimal basis for kB, MB, GB count
 FXString hSize(char* size)
 {
     int flag = 0;
@@ -930,7 +930,7 @@ FXString hSize(char* size)
     else if (lsize > 1e3)
     {
         fsize = lsize/1e3;
-        strlcpy(suf, _("KB"), sizeof(suf));
+        strlcpy(suf, _("kB"), sizeof(suf));
         flag = 1;
     }
 
